@@ -2,11 +2,11 @@
 """
 
 from .pipeline import _BaseSingleEncoder, _BaseMultipleEncoder, Pipeline, FeatureUnion
-from .custom import IdentityPreprocessingLayer
+from .custom import NumericPreprocessingLayer
 
 
 __all__ = ["_BaseSingleEncoder",
            "_BaseMultipleEncoder",
            "Pipeline",
            "FeatureUnion",
-           "IdentityPreprocessingLayer"]
+           "NumericPreprocessingLayer"]
